--addon name, addon namespace
local _, ans = ...;

local buttons = {
    QuickJoinToastButton,
    ChatFrameChannelButton,
    ChatFrameMenuButton
};
local hideTimer;

local function show()
    ans.cancelTimer(hideTimer);
    for _, button in ipairs(buttons) do
        button.customAlpha = 1;
        button:SetAlpha(1);
    end
end

local function hide()
    hideTimer = ans.createTimer(function()
        for _, button in ipairs(buttons) do
            button.customAlpha = 0;
            button:SetAlpha(0);
        end
    end);
end

local function Chat_load()
    -- move chat buttons on top of the frame
    ChatFrameChannelButton:ClearAllPoints();
    ChatFrameChannelButton:SetPoint("BOTTOMLEFT", QuickJoinToastButton, "BOTTOMRIGHT", 0, 0);
    ChatFrameMenuButton:ClearAllPoints();
    ChatFrameMenuButton:SetPoint("LEFT", ChatFrameChannelButton, "RIGHT", 0, 0);

    for i = 1, NUM_CHAT_WINDOWS do
        local frame = _G["ChatFrame"..i];
        if (frame) then
            frame:SetScript("OnEnter", show);
            frame:SetScript("OnLeave", hide);
            _G["ChatFrame"..i.."ButtonFrame"]:SetSize(0.1, 0.1);
        end
    end

    local children = { GeneralDockManager:GetChildren() };
    for _, child in ipairs(children) do
        local name = child:GetName();
        if (string.sub(name, 1, 9) == "ChatFrame") then
            -- ChatFrame items are insert into buttons table
            table.insert(buttons, child);

            -- ignoreSetAlpha is used to not go into an infinite loop of SetAlpha
            local ignoreSetAlpha = false;
            -- if a SetAlpha is called on a value different from our customAlpha it is reset to customAlpha
            hooksecurefunc(child, "SetAlpha", function(self)
                local alpha = self:GetAlpha(); 
                if (ignoreSetAlpha == false and self.customAlpha ~= nil and self.customAlpha ~= alpha) then 
                    ignoreSetAlpha = true;
                    self:SetAlpha(self.customAlpha);
                    ignoreSetAlpha = false;
                end 
            end)
        end
    end

    for _, button in ipairs(buttons) do
        button:SetScript("OnEnter", show);
        button:SetScript("OnLeave", hide);
    end

    hide();
end

ans.Chat_load = Chat_load;